@@ -2,54 +2,62 @@ package Alien::FLTK;
 {
     use strict;
     use warnings;
-    use Config qw[%Config];
     use File::Spec::Functions qw[catdir rel2abs canonpath];
-    use File::Basename;
-    use File::Find qw[find];
-    my $_config = eval do { local $/; <DATA> }
-        or warn
-        "Couldn't load Alien::FLTK configuration data: $@\n Using defaults";
-    close DATA;
-    sub new { return bless \$|, shift; }
-    sub config { return $_config; }
-    our $VERSION_BASE = 0; our $FLTK_SVN = 6921; our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf('%d.%05d' . ($UNSTABLE_RELEASE ? '_%03d' : ''), $VERSION_BASE, $FLTK_SVN, $UNSTABLE_RELEASE);
-    sub revision { return $FLTK_SVN; }
-    sub branch   { return $_config->{'fltk_branch'} }
+    our $BASE = 0; our $SVN = 7008; our $DEV = -16; our $VERSION = sprintf('%d.%05d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%03d') : ('')), $BASE, $SVN, abs $DEV);
 
-    sub include_path {
-        my ($self) = @_;
-        for my $path (catdir(qw[.. .. blib arch Alien FLTK]),
-                      catdir(qw[. blib arch Alien FLTK]),
-                      catdir(qw[Alien FLTK]))
-        {   foreach my $inc (@INC) {
-                next unless defined $inc and !ref $inc;
-                my $dir = rel2abs(
-                     catdir($inc, $path, 'include', 'fltk-' . $self->branch));
-                return $dir if -d $dir && -r $dir;
-            }
+    sub _md5 {
+        return {gz  => 'adfc4746c7b2bf7e895612d118ab8f2f',
+                bz2 => '7589b3523045b7c059026de21564e68d'
+        };
+    }
+    sub _unique_file { return 'src/Fl.cxx' }
+
+    sub new {
+        my ($class, $overrides) = @_;    # XXX - overrides are unsupported
+        my $self;
+        {
+            require File::ShareDir;
+            ($self->{'basedir'})
+                = (grep { -d $_ && -f catdir($_, 'config.yml') }
+                       map { rel2abs($_) } (
+                              eval { File::ShareDir::dist_dir('Alien-FLTK') },
+                              'share', '../share', '../../share'
+                       )
+                );
         }
-        return undef;
+        if (!defined $self->{'basedir'}) {
+            warn 'Fail';
+            return ();
+        }
+        $self->{'define'} = do {
+            require YAML::Tiny;
+            my $yaml
+                = YAML::Tiny->read(catdir($self->{'basedir'}, 'config.yml'));
+            warn 'Failed to load Alien::FLTK config: ' . YAML::Tiny->errstr()
+                if !$yaml;
+            $yaml ? $yaml->[0] : {};
+        };
+        return bless $self, shift;
+    }
+    sub config   { return +shift->{'define'}; }
+    sub revision { return $SVN; }
+    sub branch   { return +shift->{'define'}->{'branch'} }
+
+    sub include_dirs {
+        my ($self) = @_;
+        return canonpath($self->{'basedir'} . '/include');
     }
 
     sub library_path {
         my ($self) = @_;
-        for my $path (catdir(qw[.. .. blib arch Alien FLTK]),
-                      catdir(qw[. blib arch Alien FLTK]),
-                      catdir(qw[Alien FLTK]))
-        {   foreach my $inc (@INC) {
-                next unless defined $inc and !ref $inc;
-                my $dir = rel2abs(
-                        catdir($inc, $path, 'libs', 'fltk-' . $self->branch));
-                return $dir if -d $dir && -r $dir;
-            }
-        }
-        return undef;
+        return canonpath($self->{'basedir'} . '/libs');
     }
+    sub cflags { return shift->cxxflags(); }
 
-    sub cflags {
-        return $_config->{'cxxflags'} . ' -I' . shift->include_path();
+    sub cxxflags {
+        my ($self) = @_;
+        return $self->config->{'cxxflags'} ? $self->config->{'cxxflags'} : '';
     }
-    sub cxxflags { return shift->cflags() . ' -Wno-non-virtual-dtor'; }
 
     sub ldflags {    # XXX - Cache this
         my ($self, @args) = @_;
@@ -58,50 +66,47 @@ package Alien::FLTK;
         my $libdir = shift->library_path();
 
         # Calculate needed libraries
-        my $SHAREDSUFFIX = $Config{'_a'};
-        my $LDSTATIC     = sprintf '-L%s %s/libfltk%s%s %s',
-            $libdir, $libdir, ($self->branch eq '1.3.x' ? '' : '2'),
-            $SHAREDSUFFIX, $_config->{'ldflags'};
-        my $LDFLAGS = "-L$libdir " . $_config->{'ldflags'};
-        my $LIBS = sprintf '%s/libfltk%s%s', $libdir,
-            ($self->branch eq '1.3.x' ? '' : '2'),
-            $SHAREDSUFFIX;
+        my $SHAREDSUFFIX
+            = $self->config->{'_a'} ? $self->config->{'_a'}
+            : $^O =~ '$MSWin32' ? '.a'
+            :                     '.o';
+        my $LDSTATIC = sprintf '-L%s %s/libfltk%s %s', $libdir, $libdir,
+            $SHAREDSUFFIX,
+            ($self->config->{'ldflags'} ? $self->config->{'ldflags'} : '');
+        my $LDFLAGS = '-lfltk'
+            . ($self->config->{'ldflags'} ? $self->config->{'ldflags'} : '');
+        my $LIBS = sprintf '%s/libfltk%s', $libdir, $SHAREDSUFFIX;
         if (grep {m[forms]} @args) {
-            $LDFLAGS = sprintf '-lfltk%s_forms %s',
-                ($self->branch eq '1.3.x' ? '' : '2'), $LDFLAGS;
-            $LDSTATIC = sprintf '$libdir/libfltk%s_forms%s %s',
-                $libdir, ($self->branch eq '1.3.x' ? '' : '2'), $SHAREDSUFFIX,
+            $LDFLAGS  = sprintf '-lfltk_forms %s',            $LDFLAGS;
+            $LDSTATIC = sprintf '$libdir/libfltk_forms%s %s', $libdir,
+                $SHAREDSUFFIX,
                 $$LDSTATIC;
-            $LIBS = sprintf '%s %s/libfltk%s_forms%s',
-                $LIBS, $libdir, ($self->branch eq '1.3.x' ? '' : '2'),
+            $LIBS = sprintf '%s %s/libfltk_forms%s', $LIBS, $libdir,
                 $SHAREDSUFFIX;
         }
-        if ((grep {m[gl]} @args) && $_config->{'GL'}) {
-            my $LIBGL = $_config->{'GL'};
-            $LDFLAGS = sprintf '-lfltk%s_gl %s %s',
-                ($self->branch eq '1.3.x' ? '' : '2'),
-                $LIBGL, $LDFLAGS;
-            $LDSTATIC = sprintf '%s/libfltk%s_gl%s %s %s',
-                $libdir, ($self->branch eq '1.3.x' ? '' : '2'),
-                $SHAREDSUFFIX, $LIBGL, $LDSTATIC;
-            $LIBS = sprintf '%s %s/libfltk%s_gl%s',
-                $LIBS, $libdir,
-                ($self->branch eq '1.3.x' ? '' : '2'),
-                $SHAREDSUFFIX;
+        if ((grep {m[gl]} @args) && $self->config->{'GL'}) {
+            my $LIBGL = $self->config->{'GL'};
+            $LDFLAGS = sprintf '-lfltk_gl %s %s', $LIBGL, $LDFLAGS;
+            $LDSTATIC = sprintf '%s/libfltk_gl%s %s %s',
+                $libdir, $SHAREDSUFFIX, $LIBGL, $LDSTATIC;
+            $LIBS = sprintf '%s %s/libfltk_gl%s',
+                $LIBS, $libdir, $SHAREDSUFFIX;
         }
         if (grep {m[images]} @args) {
-            $LDFLAGS  = $_config->{'image_flags'} . " $LDFLAGS";
-            $LDSTATIC = sprintf '%s/libfltk%s_images%s %s %s',
-                $libdir, ($self->branch eq '1.3.x' ? '' : '2'),
-                $SHAREDSUFFIX, $LDSTATIC, $_config->{'image_flags'};
+            my $img_libs = $self->config->{'image_flags'};
+            $LDFLAGS  = " $img_libs $LDFLAGS ";
+            $LDSTATIC = sprintf '%s/libfltk_images%s %s %s',
+                $libdir, $SHAREDSUFFIX, $img_libs, $LDSTATIC;
         }
-        return (
-             ((grep {m[static]} @args) ? $LDSTATIC : $LDFLAGS) . ' -lsupc++');
+        return (  "-L$libdir "
+                . ((grep {m[static]} @args) ? $LDSTATIC : $LDFLAGS)
+                . ' -lsupc++');
     }
 
     sub capabilities {
+        my ($self) = @_;
         my @caps;
-        push @caps, 'gl' if $_config->{'config'}{'HAVE_GL'};
+        push @caps, 'gl' if $self->config->{'define'}{'HAVE_GL'};
 
         # TODO: images, forms, static(?)
         return @caps;
@@ -113,47 +118,46 @@ package Alien::FLTK;
 
 =head1 NAME
 
-Alien::FLTK - Build and use the Fast Light Toolkit binaries
+Alien::FLTK - Build and use stable C<1.3.x> branch of the Fast Light Toolkit
 
 =head1 Description
 
-This distribution builds and installs libraries for the (experimental)
-C<2.0.x> branch of the FLTK GUI toolkit.
+This distribution builds and installs libraries for the (stable) C<1.3.x>
+branch of the FLTK GUI toolkit.
 
 =head1 Synopsis
 
     use Alien::FLTK;
     use ExtUtils::CBuilder;
-    my $CC     = ExtUtils::CBuilder->new();
-    my $AF     = Alien::FLTK->new();
-    my $source = 'hello_world.cxx';
-    open(my $FH, '>', $source) || die '...';
+    my $AF  = Alien::FLTK->new();
+    my $CC  = ExtUtils::CBuilder->new();
+    my $SRC = 'hello_world.cxx';
+    open(my $FH, '>', $SRC) || die '...';
     syswrite($FH, <<'') || die '...'; close $FH;
-      #include <fltk/Window.h>
-      #include <fltk/Widget.h>
-      #include <fltk/run.h>
-      using namespace fltk;
+      #include <FL/Fl.H>
+      #include <FL/Fl_Window.H>
+      #include <FL/Fl_Box.H>
       int main(int argc, char **argv) {
-        Window *window = new Window(300, 180);
-        window->begin();
-        Widget *box = new Widget(20, 40, 260, 100, "Hello, World!");
-        box->box(UP_BOX);
-        box->labelfont(HELVETICA_BOLD_ITALIC);
+        Fl_Window *window = new Fl_Window(300,180);
+        Fl_Box *box = new Fl_Box(FL_UP_BOX, 20, 40, 260, 100, "Hello, World!");
+        box->labelfont(FL_BOLD + FL_ITALIC);
         box->labelsize(36);
-        box->labeltype(SHADOW_LABEL);
+        box->labeltype(FL_SHADOW_LABEL);
         window->end();
         window->show(argc, argv);
-        return run();
-      }
+        return Fl::run();
+    }
 
-    my $obj = $CC->compile(source               => $source,
-                           extra_compiler_flags => $AF->cxxflags());
-    my $exe = $CC->link_executable(
-                                  objects            => $obj,
-                                  extra_linker_flags => $AF->ldflags()
+    my $OBJ = $CC->compile('C++'                => 1,
+                           source               => $SRC,
+                           include_dirs         => [$AF->include_dirs()],
+                           extra_compiler_flags => $AF->cxxflags()
     );
-    print system('./' . $exe) ? 'Aww...' : 'Yay!';
-    END { unlink grep defined, $source, $obj, $exe; }
+    my $EXE =
+        $CC->link_executable(objects            => $OBJ,
+                             extra_linker_flags => $AF->ldflags());
+    print system('./' . $EXE) ? 'Aww...' : 'Yay!';
+    END { unlink grep defined, $SRC, $OBJ, $EXE; }
 
 =head1 Constructor
 
@@ -168,15 +172,16 @@ create objects with the C<new> constructor.
 After creating a new L<Alien::FLTK|Alien::FLTK> object, use the following
 methods to gather information:
 
-=head2 C<include_path>
+=head2 C<include_dirs>
 
-    my $include_path = $AF->include_path( );
+    my @include_dirs = $AF->include_dirs( );
 
-Returns the location of the headers installed during the build process.
+Returns a list of the locations of the headers installed during the build
+process and those required for compilation.
 
 =head2 C<library_path>
 
-    my $include_path = $AF->library_path( );
+    my $lib_path = $AF->library_path( );
 
 Returns the location of the private libraries we made and installed
 during the build process.
@@ -235,6 +240,16 @@ Include flags to use FLTK's forms compatibility layer.
 
 =back
 
+=head2 C<branch>
+
+    my $revision = $AF->branch( );
+
+Returns the SVN brance of the source L<Alien::FLTK|Alien::FLTK> was built
+with.
+
+Currently, L<Alien::FLTK|Alien::FLTK> defaults to the 2.0.x branch but it is
+capable of building the more stable 1.3.x branch.
+
 =head2 C<revision>
 
     my $revision = $AF->revision( );
@@ -267,7 +282,7 @@ Prerequisites differ by system...
 
 =item Win32
 
-The fltk2 libs and L<Alien::FLTK|Alien::FLTK> both build right out of the box
+The fltk libs and L<Alien::FLTK|Alien::FLTK> both build right out of the box
 with MinGW. Further testing is needed for other setups.
 
 =item X11/*nix
@@ -334,7 +349,8 @@ http://github.com/sanko/alien-fltk/ and you are invited to fork it.
 
 =head2 Examples
 
-Please see the L<Synopsis|/"Synopsis"> and the files in the C</examples/>.
+Please see the L<Synopsis|Alien::FLTK/"Synopsis"> and the files in the
+C</examples/>.
 
 =head2 Bugs
 
@@ -346,7 +362,7 @@ Please see L<Alien::FLTK::Todo|Alien::FLTK::Todo>
 
 =head1 See Also
 
-L<FLTK|FLTK>
+L<FLTK|FLTK>, L<Alien::FLTK2|Alien::FLTK2>
 
 =head1 Acknowledgments
 
@@ -379,8 +395,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 L<Alien::FLTK|Alien::FLTK> is based in part on the work of the FLTK project.
 See http://www.fltk.org/.
 
-=for git $Id: FLTK.pm 1e6c45f 2009-10-25 14:38:13Z sanko@cpan.org $
+=for git $Id: FLTK.pm 59c0964 2010-02-09 21:01:29Z sanko@cpan.org $
 
 =cut
-__DATA__
-do{ my $x = { }; $x; }
